Welcome to yweather's documentation!
====================================

:mod:`yweather` is a Python module that provides an interface to the `Yahoo! Weather RSS feed <http://developer.yahoo.com/weather/>`_.

:mod:`yweather` Documentation
-----------------------------

.. toctree::
   :maxdepth: 2

   intro
   usage
   api
   changes
   glossary



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

